"""This module provides cleanup functionality.

This is useuful to make sure any temporary resource is freed when is no longer
needed.

"""

import logging
import shutil


class Cleanup(object):

    """Cleanup object.

    This will free resources that have been added using any of the available
    methods when the run methods is executed.

    """

    def __init__(self):
        self.directories = []

    def add_directory(self, directory):
        """Add directory to be cleaned up.

        The added directory will be removed when the run method is executed.

        :param directory: The path to the directory that should be removed
        :type directory: str

        """
        self.directories.append(directory)

    def run(self):
        """Free all resources that are no longer needed."""
        for directory in self.directories:
            logging.info('Removing directory {}...'.format(directory))
            shutil.rmtree(directory)
