"""Image related functions."""

import configparser
import os

from xdg.BaseDirectory import xdg_config_home


def get_download_dir(subdir):
    """Return image download dir.

    This is a python3 port of the phabletutils.downloads.get_full_path with a
    hack to use configparser instead of configobj

    """
    try:
        userdirs_file = os.path.join(xdg_config_home, 'user-dirs.dirs')
        with open(userdirs_file) as fp:
            # Little trick to parse the file with a fake default section
            userdirs_config_str = "[DEFAULT]\n" + fp.read()
        userdirs_config = configparser.ConfigParser()
        userdirs_config.read_string(userdirs_config_str)
        userdirs_download = os.path.expandvars(
            userdirs_config.defaults()['xdg_download_dir']).strip('"')
        download_dir = userdirs_download
    except KeyError:
        download_dir = os.path.expandvars('$HOME')
    directory = os.path.join(download_dir, subdir)
    return directory
